Documentation
¶
Overview ¶
Package foreignactivation carries consent-gated MCP runtime descriptors between Plasmid packages without adding them to the public foreign catalog.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Descriptor ¶
type Descriptor struct {
ID, Transport, Command, URL string
Args []string
Env, Headers map[string]string
}
Descriptor contains secret-bearing runtime configuration. It must never be serialized into normalized catalogs, warnings, or fixtures.
Click to show internal directories.
Click to hide internal directories.